Module Bay Template - Nautobot Documentation

Skip to content

# Module Bay Templates

Added in version 2.3.0

A template for a ModuleBay that will be created on all instantiations of the parent device type or module type. Each module bay must be assigned a `position` unique to the parent.

Added in version 2.4.11

A module bay template can optionally be assigned a module family to restrict which types of modules can be installed in the bay. If a module family is specified, only modules of that family can be installed in module bays created from this template.